@@ -3,5 +3,6 @@ from .utils import Logger
 from .beautifiers import (
     CartooniseBeautifier, PencilDrawingBeautifier, CartoonGanBeautifier, FastNeuralStyleTransferBeautifier,
     DouyinEffectBeautifier, CharacterizeBeautifier, PhotomosaicBeautifier, GlitchBeautifier, CartoonizeFaceBeautifier,
-    GeneticFittingCircleBeautifier, GeneticFittingPolygonBeautifier, BezierCurveBeautifier
+    GeneticFittingCircleBeautifier, GeneticFittingPolygonBeautifier, BezierCurveBeautifier, NostalgicstyleBeautifier,
+    NoteprocessorBeautifier, OilpaintingBeautifier, PhotocorrectionBeautifier
 )
\ No newline at end of file
