@@ -37,12 +37,16 @@ class pydrawing():
             'glitch': GlitchBeautifier,
             'cartoonise': CartooniseBeautifier,
             'cartoongan': CartoonGanBeautifier,
+            'oilpainting': OilpaintingBeautifier,
             'beziercurve': BezierCurveBeautifier,
             'photomosaic': PhotomosaicBeautifier,
             'characterize': CharacterizeBeautifier,
             'douyineffect': DouyinEffectBeautifier,
+            'noteprocessor': NoteprocessorBeautifier,
             'pencildrawing': PencilDrawingBeautifier,
             'cartoonizeface': CartoonizeFaceBeautifier,
+            'nostalgicstyle': NostalgicstyleBeautifier,
+            'photocorrection': PhotocorrectionBeautifier,
             'geneticfittingcircle': GeneticFittingCircleBeautifier,
             'geneticfittingpolygon': GeneticFittingPolygonBeautifier,
             'fastneuralstyletransfer': FastNeuralStyleTransferBeautifier,
